========
Datasets
========

GUNC: Detection of Chimerism and Contamination in Prokaryotic Genomes
---------------------------------------------------------------------

Supplementary Data
^^^^^^^^^^^^^^^^^^

 - `GUNC maxCSS scores <https://swifter.embl.de/~fullam/gunc/paper_supplementary_files/All_Datasets.GUNC.scores.maxCSS_level.tsv>`_ (153M)
    md5sum: dd91aa177b9112c361b9503e132f1c06
 - `GUNC ALL scores <https://swifter.embl.de/~fullam/gunc/paper_supplementary_files/All_Datasets.GUNC.scores.all_levels.specI2species.tsv>`_ (952M)
    md5sum: a54e3719221a42a5f96b267412827d27


Synthetic Genomes
^^^^^^^^^^^^^^^^^

 - `Simulated.genomes.GUNC.scores.maxCSS_level.tsv <https://swifter.embl.de/~fullam/gunc/synthetic_genomes/Simulated.genomes.GUNC.scores.maxCSS_level.tsv>`_ (170M)
    Gunc ouput for simulated genomes - maxCSS tax level only.

    md5sum: c498e95af16ab78214fe0cf07b76f0bd
 - `Simulated.genomes.GUNC.scores.all_levels.tsv <https://swifter.embl.de/~fullam/gunc/synthetic_genomes/Simulated.genomes.GUNC.scores.all_levels.tsv>`_ (1.2G)
    Gunc ouput for simulated genomes - all tax levels.

    md5sum: fcfd7387c8205aa00ccfc27068138dbc

 - `type1.genomes.tar.gz <https://swifter.embl.de/~fullam/gunc/synthetic_genomes/type1.genomes.tar.gz>`_ (12G)
    Clean (non-contaminated) genomes, in reference. Taken from progenomes2.1.

    md5sum: 5e81105373f8a5e586e13764aa64d8f4

 - `type3a.genomes.tar.gz <https://swifter.embl.de/~fullam/gunc/synthetic_genomes/type3a.genomes.tar.gz>`_ (345G)
    Binary chimeric genome from two sources, both in reference.

    md5sum: 1bd5736a426cdee737d4fa744d272ed4

 - `type3b.genomes.tar.gz <https://swifter.embl.de/~fullam/gunc/synthetic_genomes/type3b.genomes.tar.gz>`_ (167G)
    Chimera of multiple (3, 4, or 5) source genomes, all in reference.

    md5sum: 71b3a28742fed077606d16c92eff3524
